@@ -637,8 +637,6 @@ class OpenEVSE:
     def current_capacity(self) -> int:
         """Return the current capacity."""
         assert self._status is not None
-        if self._config is not None and "max_current_soft" in self._config:
-            return self._config["max_current_soft"]
         return self._status["pilot"]
 
     @property
